<?php namespace Myriad\Installations\Validation;

use Myriad\Installations\Exceptions\InstallationValidationException;

/**
 * Interface IInstallationValidationProvider defines the methods expected by an object capable of validating
 * installations.
 *
 * @package Myriad\Installations\Validation
 */
interface IInstallationValidationProvider {

  /**
   * Get the rules used to validate an installation.
   *
   * @param array $attributes The attributes to return rules for.
   * @return array
   */
  public function getRules($attributes = []);

  /**
   * Get custom messages.
   *
   * @param array $attributes The attributes to return messages for.
   * @return array
   */
  public function getMessages($attributes = []);

  /**
   * Get a validator for the given attributes.
   *
   * @param array $attributes The attributes to get a validator for.
   * @return \Illuminate\Contracts\Validation\Validator
   */
  public function getValidator($attributes);

  /**
   * Validates a UUID.
   *
   * @param string $uuid The UUID to validate.
   * @return true
   * @throws InstallationValidationException
   */
  public function validateUUID($uuid);

  /**
   * Normalizes a UUID to string.
   *
   * @param string $uuid The UUID to validate.
   * @return string
   */
  public function normalizeUUID($uuid);

}